:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/utils.py#L167-L192



elpigraph.utils.getWeights
==========================

.. currentmodule:: elpigraph.utils

.. autofunction:: getWeights